@@ -118,6 +118,7 @@ class BadEccExchange(CryptoErr):
     ''' Raised when there is an issue doing a ECC Key Exchange '''
     pass
 
+class PathExists(SynErr): pass
 class DataAlreadyExists(SynErr):
     '''
     Cannot copy data to a location that already contains data
@@ -157,6 +158,7 @@ class NoCertKey(SynErr):
     ''' Raised when a Cert object requires a RSA Private Key to perform an operation and the key is not present.  '''
     pass
 class NoSuchCert(SynErr): pass
+class BadCertHost(SynErr): pass
 
 class ModAlreadyLoaded(SynErr): pass
 class MustBeJsonSafe(SynErr): pass
