@@ -95,6 +95,7 @@ class TimeUnit(enum.IntEnum):
     DAY = enum.auto()         # every day
     HOUR = enum.auto()
     MINUTE = enum.auto()
+    NOW = enum.auto()
 
     @classmethod
     def fromString(cls, s):
@@ -619,15 +620,22 @@ class Agenda(s_base.Base):
             reqs = [reqs]
 
         # Find all combinations of values in reqdict values and incvals values
+        nexttime = None
         recs = []  # type: ignore
         for req in reqs:
+            if TimeUnit.NOW in req:
+                if incunit is not None:
+                    mesg = "Recurring jobs may not be scheduled to run 'now'"
+                    raise ValueError(mesg)
+                nexttime = time.time()
+                continue
 
             reqdicts = self._dictproduct(req)
             if not isinstance(incvals, Iterable):
                 incvals = (incvals, )
             recs.extend(ApptRec(rd, incunit, v) for (rd, v) in itertools.product(reqdicts, incvals))
 
-        appt = _Appt(self, iden, recur, indx, query, creator, recs)
+        appt = _Appt(self, iden, recur, indx, query, creator, recs, nexttime)
         self._addappt(iden, appt)
 
         appt.doc = cdef.get('doc', '')
