@@ -23,7 +23,7 @@ import synapse.lib.stormctrl as s_stormctrl
 import synapse.lib.provenance as s_provenance
 import synapse.lib.stormtypes as s_stormtypes
 
-from synapse.lib.stormtypes import tobool, toint, toprim, tostr
+from synapse.lib.stormtypes import tobool, toint, toprim, tostr, undef
 
 logger = logging.getLogger(__name__)
 
@@ -757,16 +757,24 @@ class SetVarOper(Oper):
             count += 1
 
             valu = await vkid.compute(runt, path)
+            if valu is undef:
+                runt.popVar(name)
+                #TODO detect which to update here
+                path.popVar(name)
 
-            runt.setVar(name, valu)
-            #TODO detect which to update here
-            path.setVar(name, valu)
+            else:
+                runt.setVar(name, valu)
+                #TODO detect which to update here
+                path.setVar(name, valu)
 
             yield node, path
 
         if count == 0 and vkid.isRuntSafe(runt):
             valu = await vkid.compute(runt, None)
-            runt.setVar(name, valu)
+            if valu is undef:
+                runt.popVar(name)
+            else:
+                runt.setVar(name, valu)
 
     def getRuntVars(self, runt):
         yield self.kids[0].value(), self.kids[1].isRuntSafe(runt)
@@ -1177,19 +1185,50 @@ class LiftProp(LiftOper):
 
         assert len(self.kids) == 1
 
-        # check if we can optimize a form lift with a tag filter...
+        # check if we can optimize a form lift
         if prop.isform:
-            async for hint in self.getRightHints():
+            async for hint in self.getRightHints(runt, path):
                 if hint[0] == 'tag':
                     tagname = hint[1].get('name')
                     async for node in runt.snap.nodesByTag(tagname, form=name):
                         yield node
                     return
 
+                if hint[0] == 'relprop':
+                    relpropname = hint[1].get('name')
+                    isuniv = hint[1].get('univ')
+
+                    if isuniv:
+                        fullname = ''.join([name, relpropname])
+                    else:
+                        fullname = ':'.join([name, relpropname])
+
+                    prop = runt.model.prop(fullname)
+                    if prop is None:
+                        continue
+
+                    cmpr = hint[1].get('cmpr')
+                    valu = hint[1].get('valu')
+
+                    if cmpr is not None and valu is not None:
+                        try:
+                            # try lifting by valu but no guarantee a cmpr is available
+                            async for node in runt.snap.nodesByPropValu(fullname, cmpr, valu):
+                                yield node
+                            return
+                        except asyncio.CancelledError: # pragma: no cover
+                            raise
+                        except:
+                            pass
+
+                    async for node in runt.snap.nodesByProp(fullname):
+                        yield node
+                    return
+
         async for node in runt.snap.nodesByProp(name):
             yield node
 
-    async def getRightHints(self):
+    async def getRightHints(self, runt, path):
 
         for oper in self.iterright():
 
@@ -1198,8 +1237,11 @@ class LiftProp(LiftOper):
                 continue
 
             if isinstance(oper, FiltOper):
-                for hint in await oper.getLiftHints():
+                for hint in await oper.getLiftHints(runt, path):
                     yield hint
+                continue
+
+            return
 
 class LiftPropBy(LiftOper):
 
@@ -1785,7 +1827,7 @@ class PropPivot(PivotOper):
 
 class Cond(AstNode):
 
-    async def getLiftHints(self):
+    async def getLiftHints(self, runt, path):
         return []
 
     async def getCondEval(self, runt): # pragma: no cover
@@ -1935,9 +1977,9 @@ class AndCond(Cond):
     '''
     <cond> and <cond>
     '''
-    async def getLiftHints(self):
-        h0 = await self.kids[0].getLiftHints()
-        h1 = await self.kids[0].getLiftHints()
+    async def getLiftHints(self, runt, path):
+        h0 = await self.kids[0].getLiftHints(runt, path)
+        h1 = await self.kids[0].getLiftHints(runt, path)
         return h0 + h1
 
     async def getCondEval(self, runt):
@@ -1972,7 +2014,7 @@ class TagCond(Cond):
     '''
     #foo.bar
     '''
-    async def getLiftHints(self):
+    async def getLiftHints(self, runt, path):
 
         kid = self.kids[0]
 
@@ -2016,7 +2058,7 @@ class HasRelPropCond(Cond):
             name = await relprop.compute(runt, None)
 
             async def cond(node, path):
-                return node.has(name)
+                return await self.hasProp(node, runt, name)
 
             return cond
 
@@ -2024,10 +2066,61 @@ class HasRelPropCond(Cond):
 
         async def cond(node, path):
             name = await relprop.compute(runt, path)
-            return node.has(name)
+            return await self.hasProp(node, runt, name)
 
         return cond
 
+    async def hasProp(self, node, runt, name):
+
+        ispiv = name.find('::') != -1
+        if not ispiv:
+            return node.has(name)
+
+        # handle implicit pivot properties
+        names = name.split('::')
+
+        imax = len(names) - 1
+        for i, part in enumerate(names):
+
+            valu = node.get(part)
+            if valu is None:
+                return False
+
+            if i >= imax:
+                return True
+
+            prop = node.form.props.get(part)
+            if prop is None:
+                raise s_exc.NoSuchProp(name=part, form=node.form.name)
+
+            form = runt.model.forms.get(prop.type.name)
+            if form is None:
+                raise s_exc.NoSuchForm(name=prop.type.name)
+
+            node = await runt.snap.getNodeByNdef((form.name, valu))
+            if node is None:
+                return False
+
+    async def getLiftHints(self, runt, path):
+
+        relprop = self.kids[0]
+
+        name = await relprop.compute(runt, path)
+        ispiv = name.find('::') != -1
+        if ispiv:
+            return (
+                ('relprop', {'name': name.split('::')[0]}),
+            )
+
+        hint = {
+            'name': name,
+            'univ': isinstance(relprop, UnivProp),
+        }
+
+        return (
+            ('relprop', hint),
+        )
+
 class HasTagPropCond(Cond):
 
     async def getCondEval(self, runt):
@@ -2201,6 +2294,28 @@ class RelPropCond(Cond):
 
         return cond
 
+    async def getLiftHints(self, runt, path):
+
+        relprop = self.kids[0].kids[0]
+
+        name = await relprop.compute(runt, path)
+        ispiv = name.find('::') != -1
+        if ispiv:
+            return (
+                ('relprop', {'name': name.split('::')[0]}),
+            )
+
+        hint = {
+            'name': name,
+            'univ': isinstance(relprop, UnivProp),
+            'cmpr': await self.kids[1].compute(runt, path),
+            'valu': await self.kids[2].compute(runt, path),
+        }
+
+        return (
+            ('relprop', hint),
+        )
+
 class TagPropCond(Cond):
 
     async def getCondEval(self, runt):
@@ -2232,12 +2347,12 @@ class TagPropCond(Cond):
 
 class FiltOper(Oper):
 
-    async def getLiftHints(self):
+    async def getLiftHints(self, runt, path):
 
         if await self.kids[0].compute(None, None) != '+':
             return []
 
-        return await self.kids[1].getLiftHints()
+        return await self.kids[1].getLiftHints(runt, path)
 
     async def run(self, runt, genr):
 
