@@ -181,7 +181,7 @@ class Hive(s_nexus.Pusher, s_telepath.Aware):
     async def _onHiveFini(self):
         await self.root.fini()
 
-    async def get(self, full):
+    async def get(self, full, defv=None):
         '''
         Get the value of a node at a given path.
 
@@ -194,7 +194,7 @@ class Hive(s_nexus.Pusher, s_telepath.Aware):
 
         node = self.nodes.get(full)
         if node is None:
-            return None
+            return defv
 
         return node.valu
 
