@@ -5,7 +5,9 @@ coremods = (
     'synapse.models.dns.DnsModule',
     'synapse.models.orgs.OuModule',
     'synapse.models.syn.SynModule',
+    'synapse.models.auth.AuthModule',
     'synapse.models.base.BaseModule',
+    'synapse.models.risk.RiskModule',
     'synapse.models.person.PsModule',
     'synapse.models.files.FileModule',
     'synapse.models.infotech.ItModule',
@@ -21,4 +23,5 @@ coremods = (
     'synapse.models.gov.us.GovUsModule',
     'synapse.models.gov.intl.GovIntlModule',
     'synapse.models.economic.EconModule',
+    'synapse.models.transport.TransportModule',
 )
