@@ -465,8 +465,8 @@ ruleClassMap = {
     'edittagpropdel': s_ast.EditTagPropDel,
     'editunivdel': s_ast.EditUnivDel,
     'editunivset': s_ast.EditPropSet,
-    'expror': s_ast.ExprNode,
-    'exprand': s_ast.ExprNode,
+    'expror': s_ast.ExprOrNode,
+    'exprand': s_ast.ExprAndNode,
     'exprnot': s_ast.UnaryExprNode,
     'exprcmp': s_ast.ExprNode,
     'exprproduct': s_ast.ExprNode,
