@@ -50,6 +50,12 @@ class EchoAuth(s_cell.Cell):
         if doraise:
             raise s_exc.BadTime(mesg='call again later')
 
+async def altAuthCtor(cell):
+    authconf = cell.conf.get('auth:conf')
+    assert authconf['foo'] == 'bar'
+    authconf['baz'] = 'faz'
+    return await s_cell.Cell._initCellHiveAuth(cell)
+
 class CellTest(s_t_utils.SynTest):
 
     async def test_cell_auth(self):
@@ -638,3 +644,39 @@ class CellTest(s_t_utils.SynTest):
 
                     with self.raises(s_exc.BadArg):
                         await proxy.runBackup(name='foo/bar')
+
+    async def test_cell_tls_client(self):
+
+        with self.getTestDir() as dirn:
+
+            async with self.getTestCryo(dirn=dirn) as cryo:
+
+                cryo.certdir.genCaCert('localca')
+                cryo.certdir.genHostCert('localhost', signas='localca')
+                cryo.certdir.genUserCert('root@localhost', signas='localca')
+
+                root = await cryo.auth.addUser('root@localhost')
+                await root.setAdmin(True)
+
+            async with self.getTestCryo(dirn=dirn) as cryo:
+
+                addr, port = await cryo.dmon.listen('ssl://0.0.0.0:0?hostname=localhost&ca=localca')
+
+                async with await s_telepath.openurl(f'ssl://root@127.0.0.1:{port}?hostname=localhost') as proxy:
+                    self.nn(await proxy.getCellIden())
+
+                with self.raises(s_exc.BadCertHost):
+                    async with await s_telepath.openurl(f'ssl://root@127.0.0.1:{port}?hostname=borked.localhost') as proxy:
+                        pass
+
+    async def test_cell_auth_ctor(self):
+        conf = {
+            'auth:ctor': 'synapse.tests.test_lib_cell.altAuthCtor',
+            'auth:conf': {
+                'foo': 'bar',
+            },
+        }
+        with self.getTestDir() as dirn:
+            async with await s_cell.Cell.anit(dirn, conf=conf) as cell:
+                self.eq('faz', cell.conf.get('auth:conf')['baz'])
+                await cell.auth.addUser('visi')
