@@ -7,6 +7,7 @@ import synapse.datamodel as s_datamodel
 
 import synapse.lib.storm as s_storm
 import synapse.lib.version as s_version
+import synapse.lib.httpapi as s_httpapi
 
 import synapse.tests.utils as s_t_utils
 from synapse.tests.utils import alist
@@ -94,6 +95,8 @@ class StormTest(s_t_utils.SynTest):
             self.len(1, await core.nodes('$x = $lib.null if ($lib.true or $x > 20) { [ ps:contact=* ] }'))
 
             visi = await core.auth.addUser('visi')
+            await visi.setPasswd('secret')
+
             cmd0 = {
                 'name': 'asroot.not',
                 'storm': '[ ou:org=* ]',
@@ -174,6 +177,104 @@ class StormTest(s_t_utils.SynTest):
             self.true(await core.callStorm('return($lib.version.matches($lib.version.synapse(), ">=2.9.0"))'))
             self.false(await core.callStorm('return($lib.version.matches($lib.version.synapse(), ">0.0.1,<2.0"))'))
 
+            # test out the stormlib axon API
+            host, port = await core.addHttpsPort(0, host='127.0.0.1')
+
+            opts = {'user': visi.iden, 'vars': {'port': port}}
+            wget = '''
+                $url = $lib.str.format("https://visi:secret@127.0.0.1:{port}/api/v1/healthcheck", port=$port)
+                return($lib.axon.wget($url, ssl=$lib.false))
+            '''
+            with self.raises(s_exc.AuthDeny):
+                await core.callStorm(wget, opts=opts)
+
+            await visi.addRule((True, ('storm', 'lib', 'axon', 'wget')))
+            resp = await core.callStorm(wget, opts=opts)
+            self.true(resp['ok'])
+
+    async def test_storm_undef(self):
+
+        async with self.getTestCore() as core:
+
+            # pernode variants
+            self.none(await core.callStorm('''
+                [ ps:contact = * ]
+                if $node {
+                    $foo = $lib.dict()
+                    $foo.bar = $lib.undef
+                    return($foo.bar)
+                }
+            '''))
+            with self.raises(s_exc.NoSuchVar):
+                await core.callStorm('[ps:contact=*] $foo = $node.repr() $foo = $lib.undef return($foo)')
+
+            with self.raises(s_exc.StormRuntimeError):
+                await core.callStorm('''
+                    [ps:contact=*]
+                    $path.vars.foo = lol
+                    $path.vars.foo = $lib.undef
+                    return($path.vars.foo)
+                ''')
+
+            # runtsafe variants
+            self.eq(('foo', 'baz'), await core.callStorm('$foo = (foo, bar, baz) $foo.1 = $lib.undef return($foo)'))
+            self.eq(('foo', 'bar'), await core.callStorm('$foo = (foo, bar, baz) $foo."-1" = $lib.undef return($foo)'))
+            self.none(await core.callStorm('$foo = $lib.dict() $foo.bar = 10 $foo.bar = $lib.undef return($foo.bar)'))
+            self.eq(('woot',), await core.callStorm('''
+                $foo = (foo, bar, baz)
+                $foo.0 = $lib.undef
+                $foo.0 = $lib.undef
+                $foo.0 = $lib.undef
+                // one extra to test the exc handler
+                $foo.0 = $lib.undef
+                $foo.append(hehe)
+                $foo.0 = woot
+                return($foo)
+            '''))
+            with self.raises(s_exc.NoSuchVar):
+                await core.callStorm('$foo = 10 $foo = $lib.undef return($foo)')
+
+    async def test_storm_pkg_load(self):
+        cont = s_common.guid()
+        pkg = {
+            'name': 'testload',
+            'version': (0, 3, 0),
+            'modules': (
+                {
+                    'name': 'testload',
+                    'storm': 'function x() { return((0)) }',
+                },
+            ),
+            'onload': f'[ ps:contact={cont} ] $lib.print(teststring) return($path.vars.newp)'
+        }
+        class PkgHandler(s_httpapi.Handler):
+
+            async def get(self, name):
+
+                if name == 'notok':
+                    self.sendRestErr('FooBar', 'baz faz')
+                    return
+
+                self.sendRestRetn(pkg)
+
+        async with self.getTestCore() as core:
+            core.addHttpApi('/api/v1/pkgtest/(.*)', PkgHandler, {'cell': core})
+            port = (await core.addHttpsPort(0, host='127.0.0.1'))[1]
+
+            msgs = await core.stormlist(f'pkg.load --ssl-noverify https://127.0.0.1:{port}/api/v1/newp/newp')
+            self.stormIsInWarn('pkg.load got HTTP code: 404', msgs)
+
+            msgs = await core.stormlist(f'pkg.load --ssl-noverify https://127.0.0.1:{port}/api/v1/pkgtest/notok')
+            self.stormIsInWarn('pkg.load got JSON error: FooBar', msgs)
+
+            with self.getAsyncLoggerStream('synapse.cortex',
+                                      "{'mesg': 'teststring'}") as stream:
+                msgs = await core.stormlist(f'pkg.load --ssl-noverify https://127.0.0.1:{port}/api/v1/pkgtest/yep')
+                self.stormIsInPrint('testload @0.3.0', msgs)
+                self.true(await stream.wait(6))
+
+            self.len(1, await core.nodes(f'ps:contact={cont}'))
+
     async def test_storm_tree(self):
 
         async with self.getTestCore() as core:
