@@ -220,12 +220,14 @@ class GeoTest(s_t_utils.SynTest):
 
             async with await core.snap() as snap:
                 guid = s_common.guid()
+                fbyts = s_common.guid()
                 parent = s_common.guid()
                 props = {'name': 'Vertex  HQ',
                          'desc': 'The place where Vertex Project hangs out at!',
                          'address': '208 Datong Road, Pudong District, Shanghai, China',
                          'parent': parent,
                          'loc': 'us.hehe.haha',
+                         'photo': f'guid:{fbyts}',
                          'latlong': '34.1341, -118.3215',
                          'bbox': '2.11, 2.12, -4.88, -4.9',
                          'radius': '1.337km'}
@@ -238,6 +240,7 @@ class GeoTest(s_t_utils.SynTest):
                 self.eq(node.get('desc'), 'The place where Vertex Project hangs out at!')
                 self.eq(node.get('address'), '208 datong road, pudong district, shanghai, china')
                 self.eq(node.get('parent'), parent)
+                self.eq(node.get('photo'), f'guid:{fbyts}')
 
                 self.eq(node.get('bbox'), (2.11, 2.12, -4.88, -4.9))
                 self.eq(node.repr('bbox'), '2.11,2.12,-4.88,-4.9')
