@@ -576,6 +576,10 @@ class InetModelTest(s_t_utils.SynTest):
 
     async def test_http_request(self):
         formname = 'inet:http:request'
+
+        client = s_common.guid()
+        server = s_common.guid()
+
         input_props = {
             'time': '2015',
             'flow': 32 * 'f',
@@ -589,7 +593,9 @@ class InetModelTest(s_t_utils.SynTest):
             'response:code': 200,
             'response:reason': 'OK',
             'response:headers': (('baz', 'faz'),),
-            'response:body': 64 * 'b'
+            'response:body': 64 * 'b',
+            'client:host': client,
+            'server:host': server,
         }
         expected_props = {
             'time': 1420070400000,
@@ -603,6 +609,10 @@ class InetModelTest(s_t_utils.SynTest):
 
             'server:port': 443,
             'server:ipv4': 0x05050505,
+
+            'client:host': client,
+            'server:host': server,
+
             'headers': (('foo', 'bar'),),
 
             'response:code': 200,
@@ -678,10 +688,12 @@ class InetModelTest(s_t_utils.SynTest):
             self.eq(2851995905, norm)
             self.eq(info.get('subs').get('type'), 'linklocal')
 
-            # Demonstrate wrap-around
-            info = {'subs': {'type': 'private'}}
-            self.eq(t.norm(0x00000000 - 1), (2**32 - 1, info))
-            self.eq(t.norm(0xFFFFFFFF + 1), (0, info))
+            # Don't allow invalid values
+            with self.raises(s_exc.BadTypeValu):
+                t.norm(0x00000000 - 1)
+
+            with self.raises(s_exc.BadTypeValu):
+                t.norm(0xFFFFFFFF + 1)
 
             # Form Tests ======================================================
             place = s_common.guid()
@@ -711,16 +723,15 @@ class InetModelTest(s_t_utils.SynTest):
             # > / < lifts and filters
             self.len(4, await core.nodes('[inet:ipv4=0 inet:ipv4=1 inet:ipv4=2 inet:ipv4=3]'))
             # Lifts
-            with self.raises(OverflowError):
-                await core.nodes('inet:ipv4<0')
+            self.len(0, await core.nodes('inet:ipv4<0'))
             self.len(1, await core.nodes('inet:ipv4<=0'))
             self.len(1, await core.nodes('inet:ipv4<1'))
             self.len(3, await core.nodes('inet:ipv4<=2'))
             self.len(2, await core.nodes('inet:ipv4>2'))
             self.len(3, await core.nodes('inet:ipv4>=2'))
             self.len(0, await core.nodes('inet:ipv4>=255.0.0.1'))
-            # This value wraps around and lifts starting from zero.
-            self.len(5, await core.nodes('inet:ipv4>=$foo', {'vars': {'foo': 0xFFFFFFFF + 1}}))
+            with self.raises(s_exc.BadTypeValu):
+                self.len(5, await core.nodes('inet:ipv4>=$foo', {'vars': {'foo': 0xFFFFFFFF + 1}}))
             # Filters
             self.len(0, await core.nodes('.created +inet:ipv4<0'))
             self.len(1, await core.nodes('.created +inet:ipv4<1'))
@@ -1910,16 +1921,21 @@ class InetModelTest(s_t_utils.SynTest):
     async def test_search_query(self):
         async with self.getTestCore() as core:
             async with await core.snap() as snap:
+                host = s_common.guid()
                 props = {
                     'time': 200,
                     'text': 'hi there',
                     'engine': 'roofroof',
+                    'host': host,
+                    'acct': 'vertex.link/visi',
                 }
                 iden = s_common.guid()
                 node = await snap.addNode('inet:search:query', iden, props=props)
                 self.eq(node.get('time'), 200)
                 self.eq(node.get('text'), 'hi there')
                 self.eq(node.get('engine'), 'roofroof')
+                self.eq(node.get('host'), host)
+                self.eq(node.get('acct'), ('vertex.link', 'visi'))
                 props = {
                     'query': iden,
                     'url': 'http://hehehaha.com/',
