@@ -20,7 +20,6 @@ import synapse.lib.cell as s_cell
 import synapse.lib.coro as s_coro
 import synapse.lib.share as s_share
 import synapse.lib.httpapi as s_httpapi
-import synapse.lib.urlhelp as s_urlhelp
 import synapse.lib.version as s_version
 
 import synapse.tests.utils as s_t_utils
@@ -369,6 +368,7 @@ class TeleTest(s_t_utils.SynTest):
 
             dmon.certdir.genCaCert('userca')
             dmon.certdir.genUserCert('visi', signas='userca')
+            dmon.certdir.genUserCert('visi@localhost', signas='userca')
 
             addr, port = await dmon.listen('ssl://127.0.0.1:0/?ca=userca&hostname=localhost')
             dmon.share('foo', foo)
@@ -376,8 +376,11 @@ class TeleTest(s_t_utils.SynTest):
             with self.raises(s_exc.LinkShutDown):
                 await s_telepath.openurl(f'ssl://localhost/foo', port=port, certdir=dmon.certdir)
 
-            proxy = await s_telepath.openurl(f'ssl://localhost/foo?certname=visi', port=port, certdir=dmon.certdir)
-            self.eq(20, await proxy.bar(15, 5))
+            async with await s_telepath.openurl(f'ssl://localhost/foo?certname=visi', port=port, certdir=dmon.certdir) as proxy:
+                self.eq(20, await proxy.bar(15, 5))
+
+            async with await s_telepath.openurl(f'ssl://visi@localhost/foo', port=port, certdir=dmon.certdir) as proxy:
+                self.eq(20, await proxy.bar(15, 5))
 
     async def test_telepath_tls(self):
         self.thisHostMustNot(platform='darwin')
@@ -1010,7 +1013,7 @@ class TeleTest(s_t_utils.SynTest):
                 consul = f'https://127.0.0.1:{hport}'
 
                 burl = f'tcp+consul://root:root@foobar/*?consul_nosslverify=1&consul={consul}'
-                info = s_urlhelp.chopurl(burl)
+                info = s_telepath.chopurl(burl)
                 self.eq(info.get('host'), 'foobar')
                 self.none(info.get('port'))
 
@@ -1022,14 +1025,14 @@ class TeleTest(s_t_utils.SynTest):
 
                 # Support tag_address and service_tag_address
                 url = burl + '&consul_tag_address=wan'
-                info = s_urlhelp.chopurl(url)
+                info = s_telepath.chopurl(url)
                 await s_telepath.disc_consul(info)
                 self.eq(info.get('host'), '10.0.10.10')
                 self.eq(info.get('port'), 5000)
                 self.eq(info.get('original_host'), 'foobar')
 
                 url = burl + '&consul_service_tag_address=wan'
-                info = s_urlhelp.chopurl(url)
+                info = s_telepath.chopurl(url)
                 await s_telepath.disc_consul(info)
                 self.eq(info.get('host'), '198.18.0.1')
                 self.eq(info.get('port'), 512)
@@ -1037,7 +1040,7 @@ class TeleTest(s_t_utils.SynTest):
 
                 # Support servicetag based port finding
                 url = burl + '&consul_tag=tacos'
-                info = s_urlhelp.chopurl(url)
+                info = s_telepath.chopurl(url)
                 await s_telepath.disc_consul(info)
                 self.eq(info.get('host'), '192.168.10.10')
                 self.eq(info.get('port'), 5000)
@@ -1052,21 +1055,21 @@ class TeleTest(s_t_utils.SynTest):
                 # Sad path - non-existing service name.
                 with self.raises(s_exc.BadUrl) as cm:
                     url = f'tcp+consul://root:root@newp/*?consul_nosslverify=1&consul={consul}'
-                    await s_telepath.disc_consul(s_urlhelp.chopurl(url))
+                    await s_telepath.disc_consul(s_telepath.chopurl(url))
                 self.eq(cm.exception.get('name'), 'newp')
 
                 # Sad path - multiple tag resolution.
                 with self.raises(s_exc.BadUrl) as cm:
                     url = burl + '&consul_tag_address=wan'
                     url = url + '&consul_service_tag_address=lan'
-                    await s_telepath.disc_consul(s_urlhelp.chopurl(url))
+                    await s_telepath.disc_consul(s_telepath.chopurl(url))
                 self.eq(cm.exception.get('consul_tag_address'), 'wan')
                 self.eq(cm.exception.get('consul_service_tag_address'), 'lan')
 
                 # Sad path - ssl verification failure
                 with self.raises(s_exc.BadUrl) as cm:
                     url = f'tcp+consul://root:root@foobar/*?consul={consul}'
-                    await s_telepath.disc_consul(s_urlhelp.chopurl(url))
+                    await s_telepath.disc_consul(s_telepath.chopurl(url))
                 self.isin('certificate verify failed', cm.exception.get('mesg'))
                 self.isinstance(cm.exception.__context__, ssl.SSLCertVerificationError)
 
@@ -1077,12 +1080,14 @@ class TeleTest(s_t_utils.SynTest):
                 cell.consul_data.insert(0, new_data)
                 with self.raises(s_exc.BadUrl) as cm:
                     url = burl + '&consul_tag=burritos'
-                    await s_telepath.disc_consul(s_urlhelp.chopurl(url))
+                    await s_telepath.disc_consul(s_telepath.chopurl(url))
                 self.eq('burritos', cm.exception.get('tag'))
 
     async def test_telepath_client_onlink_exc(self):
 
         cnts = {
+            'ok': 0,
+            'exc': 0,
             'loops': 0,
             'inits': 0
         }
@@ -1101,8 +1106,15 @@ class TeleTest(s_t_utils.SynTest):
 
             await originit(self, url)
 
-        def onlinkFail(self):
-            raise ValueError('derp')
+        async def onLinkOk(p):
+            cnts['ok'] += 1
+
+        async def onlinkFail(p):
+            await p.fini()
+
+        async def onlinkExc(p):
+            cnts['exc'] += 1
+            raise s_exc.SynErr(mesg='ohhai')
 
         foo = Foo()
 
@@ -1110,14 +1122,29 @@ class TeleTest(s_t_utils.SynTest):
             dmon.share('foo', foo)
             url = f'tcp://127.0.0.1:{dmon.addr[1]}/foo'
 
+            async with await s_telepath.Client.anit(url) as targ:
+                proxy = await targ.proxy(timeout=2)
+                await targ.onlink(onLinkOk)
+                self.eq(1, cnts['ok'])
+                with self.raises(s_exc.SynErr):
+                    await targ.onlink(onlinkExc)
+                self.eq(1, cnts['exc'])
+
             with mock.patch('synapse.telepath.Client._fireLinkLoop', countLinkLoops):
                 with mock.patch('synapse.telepath.Client._initTeleLink', countInitLinks):
                     async with await s_telepath.Client.anit(url, onlink=onlinkFail) as targ:
 
                         self.true(await asyncio.wait_for(evnt.wait(), timeout=6))
-                        self.eq(1, cnts['loops'])
+                        self.eq(4, cnts['loops'])
                         self.eq(4, cnts['inits'])
 
+                    evnt.clear()
+                    async with await s_telepath.Client.anit(url, onlink=onlinkExc) as targ:
+
+                        self.true(await asyncio.wait_for(evnt.wait(), timeout=6))
+                        self.eq(5, cnts['loops'])
+                        self.eq(5, cnts['inits'])
+
     async def test_client_method_reset(self):
         class Foo:
             def __init__(self):
@@ -1172,3 +1199,32 @@ class TeleTest(s_t_utils.SynTest):
                     self.eq(await prox.bar(), 'bar')
                     # We still have foo and bar as named meths
                     self.eq(prox._t_named_meths, {'foo', 'bar'})
+
+    async def test_telepath_loadenv(self):
+        with self.getTestDir() as dirn:
+
+            certpath = s_common.gendir(dirn, 'certs')
+            newppath = s_common.genpath(dirn, 'newps')
+
+            conf = {
+                'version': 1,
+                'aha:servers': [
+                    'tcp://localhost:9999/',
+                ],
+                'certdirs': [
+                    certpath,
+                    newppath,
+                ],
+            }
+
+            path = s_common.genpath(dirn, 'telepath.yaml')
+            s_common.yamlsave(conf, path)
+
+            fini = await s_telepath.loadTeleEnv(path)
+            await fini()
+
+            self.none(await s_telepath.loadTeleEnv(newppath))
+
+            conf['version'] = 99
+            s_common.yamlsave(conf, path)
+            self.none(await s_telepath.loadTeleEnv(path))
