@@ -18,7 +18,7 @@ import synapse.lib.encoding as s_encoding
 
 logger = logging.getLogger(__name__)
 
-reqver = '>=0.1.0,<0.2.0'
+reqver = '>=0.2.0,<3.0.0'
 
 def getItems(*paths):
     items = []
@@ -133,7 +133,7 @@ def makeargparser():
 
     pars.add_argument('--debug', '-d', default=False, action='store_true',
                       help='Drop to interactive prompt to inspect cortex after loading data.')
-    pars.add_argument('--format', '-f', type=str, action='store', default='syn.ingest',
+    pars.add_argument('--format', '-f', type=str, action='store', default='syn.nodes',
                       help='Feed format to use for the ingested data.')
     pars.add_argument('--modules', '-m', type=str, action='append', default=[],
                       help='Additional modules to load locally with a test Cortex.')
